==> was-plugin-1.2.2-sources.jar: com/xebialabs/deployit/plugin/was/step/CreateWasWmqQueueConnectionFactoryStep.java <==
/*
 * Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to  (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.step;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.plugin.was.ci.WasCluster;
import com.xebialabs.deployit.plugin.was.ci.WasServer;
import com.xebialabs.deployit.plugin.was.ci.WasWmqQueueConnectionFactory;
import com.xebialabs.deployit.util.ExtendedStringUtils;

/**
 * Creates a {@link WasWmqQueueConnectionFactory} in a {@link WasCluster}
 */
@SuppressWarnings("serial")
public class CreateWasWmqQueueConnectionFactoryStep extends WasStepBase implements Step {

	public static String CREATE_WMQ_QCF_SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-wmq-queue-connection-factory.py";

	private WasCluster cluster;
	private WasServer server;

	private WasWmqQueueConnectionFactory qcf;

	public CreateWasWmqQueueConnectionFactoryStep(WasCluster cluster, WasWmqQueueConnectionFactory qcf) {
		super(cluster.getCell());
		this.cluster = cluster;
		this.server = null;
		this.qcf = qcf;
		setDescription("Create WebSphere MQ Queue Connection Factory " + ExtendedStringUtils.getQuotedString(qcf.getLabel()) + " in cluster " + cluster.getLabel());
	}
	
	public CreateWasWmqQueueConnectionFactoryStep(WasServer server, WasWmqQueueConnectionFactory qcf) {
		super(server.getNode().getCell());
		this.cluster = null;
		this.server = server;
		this.qcf = qcf;
		setDescription("Create WebSphere MQ Queue Connection Factory " + ExtendedStringUtils.getQuotedString(qcf.getLabel()) + " in server " + server.getLabel());
	}

	public boolean execute(StepExecutionContext ctx) {
		Map<String, Serializable> context = new HashMap<String, Serializable>();
		if (cluster != null) {
			context.put("cluster", cluster);
		}
		if (server != null) {
			context.put("server", server);
			context.put("node", server.getNode());
			context.put("cell", server.getNode().getCell());
		}
		context.put("qcf", qcf);
		context.put("qcfQueueManagerHost", qcf.getQueueManagerHost());
		int res = executeWsadminJythonScriptResource(ctx, context, CREATE_WMQ_QCF_SCRIPT_RESOURCE_PATH);
		return res == 0;
	}

}

==> was-plugin-1.3.2.1-sources.jar: com/xebialabs/deployit/plugin/was/step/CreateWasWmqQueueConnectionFactoryStep.java <==
/*
 * Copyright (c) 2008-2010 XebiaLabs B.V. All rights reserved.
 *
 * Your use of XebiaLabs Software and Documentation is subject to the Personal
 * License Agreement.
 *
 * http://www.xebialabs.com/deployit-personal-edition-license-agreement
 *
 * You are granted a personal license (i) to use the Software for your own
 * personal purposes which may be used in a production environment and/or (ii)
 * to use the Documentation to develop your own plugins to the Software.
 * "Documentation" means the how to's and instructions (instruction videos)
 * provided with the Software and/or available on the XebiaLabs website or other
 * websites as well as the provided API documentation, tutorial and access to
 * the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
 * or sublicense the Software or Documentation to any third party, or otherwise
 * use it except as permitted in this agreement; (ii) reverse engineer,
 * decompile, disassemble, or otherwise attempt to determine source code or
 * protocols from the Software, and/or to (iii) copy the Software or
 * Documentation (which includes the source code of the XebiaLabs plugins). You
 * shall not create or attempt to create any derivative works from the Software
 * except and only to the extent permitted by law. You will preserve XebiaLabs'
 * copyright and legal notices on the Software and Documentation. XebiaLabs
 * retains all rights not expressly granted to You in the Personal License
 * Agreement.
 */

package com.xebialabs.deployit.plugin.was.step;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;

import com.xebialabs.deployit.Step;
import com.xebialabs.deployit.StepExecutionContext;
import com.xebialabs.deployit.plugin.was.ci.WasTarget;
import com.xebialabs.deployit.plugin.was.ci.WasWmqQueueConnectionFactory;

/**
 * Creates a {@link WasWmqQueueConnectionFactory} in a {@link WasTarget}
 */
@SuppressWarnings("serial")
public class CreateWasWmqQueueConnectionFactoryStep extends WasStepBase implements Step {

	public static String CREATE_WMQ_QCF_SCRIPT_RESOURCE_PATH = STEP_RESOURCES_PATH + "create-wmq-queue-connection-factory.py";

	private WasTarget target;

	private WasWmqQueueConnectionFactory qcf;

	public CreateWasWmqQueueConnectionFactoryStep(WasTarget target, WasWmqQueueConnectionFactory qcf) {
		super(target.getCell());
		this.target = target;
		this.qcf = qcf;
		setDescription("Create WebSphere MQ Queue Connection Factory " + qcf + " in " + target.getShortTypeDescription() + " " + target);
	}

	public boolean execute(StepExecutionContext ctx) {
		Map<String, Serializable> context = new HashMap<String, Serializable>();
		context.put("qcf", qcf);
		context.put("qcfQueueManagerHost", qcf.getQueueManagerHost());

		String jmsProviderContainmentPath = "/" + target.getWasConfigIdType() + ":" + target.getName() + "/JMSProvider:WebSphere MQ JMS Provider";
		int res = executeWsadminJythonScriptResource(ctx, context, CREATE_WMQ_QCF_SCRIPT_RESOURCE_PATH, jmsProviderContainmentPath);
		return res == 0;
	}

}
